@@ -1,5 +1,5 @@
 
-# $Id: RandomForest.R 630 2017-02-27 14:58:59Z thothorn $
+# $Id: RandomForest.R 648 2018-03-26 12:18:17Z thothorn $
 
 ### the fitting procedure
 cforestfit <- function(object, controls, weights = NULL, ...) {
@@ -121,12 +121,12 @@ cforestfit <- function(object, controls, weights = NULL, ...) {
     }
 
     RET@prediction_weights <- function(newdata = NULL, 
-                                       mincriterion = 0, OOB = FALSE) {
+                                       mincriterion = 0, OOB = FALSE, scale = TRUE) {
 
         newinp <- newinputs(object, newdata)
 
         RET <- .Call(R_predictRF_weights, RET@ensemble, RET@where, RET@weights, 
-                     newinp, mincriterion, OOB && is.null(newdata))
+                     newinp, mincriterion, OOB && is.null(newdata), scale)
         names(RET) <- rownames(newinp@variables)
         RET
     }
